@@ -7,11 +7,14 @@ SWFDEC_AS_CONSTRUCTOR (107, 2, swfdec_as_boolean_construct, swfdec_as_boolean_ge
 SWFDEC_AS_CONSTRUCTOR (103, 256, swfdec_as_date_construct, swfdec_as_date_get_type)
 SWFDEC_AS_CONSTRUCTOR (106, 2, swfdec_as_number_construct, swfdec_as_number_get_type)
 SWFDEC_AS_CONSTRUCTOR (251, 0, swfdec_as_string_construct, swfdec_as_string_get_type)
+SWFDEC_AS_CONSTRUCTOR (1100, 0, swfdec_bitmap_data_construct, swfdec_bitmap_data_get_type)
+SWFDEC_AS_CONSTRUCTOR (1105, 0, swfdec_color_transform_as_construct, swfdec_color_transform_as_get_type)
 SWFDEC_AS_CONSTRUCTOR (112, 0, swfdec_movie_clip_loader_construct, swfdec_movie_clip_loader_get_type)
 SWFDEC_AS_CONSTRUCTOR (2100, 200, swfdec_net_connection_construct, swfdec_net_connection_get_type)
 SWFDEC_AS_CONSTRUCTOR (500, 16, swfdec_sound_object_construct, swfdec_sound_object_get_type)
 SWFDEC_AS_CONSTRUCTOR (113, 0, swfdec_style_sheet_construct, swfdec_style_sheet_get_type)
 SWFDEC_AS_CONSTRUCTOR (110, 0, swfdec_text_format_construct, swfdec_text_format_get_type)
+SWFDEC_AS_CONSTRUCTOR (1106, 0, swfdec_transform_as_construct, swfdec_transform_as_get_type)
 SWFDEC_AS_CONSTRUCTOR (253, 0, swfdec_xml_node_construct, swfdec_xml_node_get_type)
 SWFDEC_AS_CONSTRUCTOR (253, 9, swfdec_xml_construct, swfdec_xml_get_type)
 SWFDEC_AS_NATIVE (1999, 0, swfdec_accessibility_isActive)
@@ -183,10 +186,9 @@ SWFDEC_AS_NATIVE (1100, 18, swfdec_bitmap_data_merge)
 SWFDEC_AS_NATIVE (1100, 19, swfdec_bitmap_data_noise)
 SWFDEC_AS_NATIVE (1100, 20, swfdec_bitmap_data_copyChannel)
 SWFDEC_AS_NATIVE (1100, 21, swfdec_bitmap_data_clone)
-SWFDEC_AS_NATIVE (1100, 22, swfdec_bitmap_data_dispose)
+SWFDEC_AS_NATIVE (1100, 22, swfdec_bitmap_data_do_dispose)
 SWFDEC_AS_NATIVE (1100, 23, swfdec_bitmap_data_generateFilterRect)
 SWFDEC_AS_NATIVE (1100, 24, swfdec_bitmap_data_compare)
-SWFDEC_AS_NATIVE (1100, 0, swfdec_bitmap_data_construct)
 SWFDEC_AS_NATIVE (1112, 1, swfdec_bitmap_filter_getPixel)
 SWFDEC_AS_NATIVE (1112, 0, swfdec_bitmap_filter_construct)
 SWFDEC_AS_NATIVE (1102, 1, swfdec_blur_filter_get_blurX)
@@ -221,26 +223,25 @@ SWFDEC_AS_NATIVE (700, 1, swfdec_movie_color_setTransform)
 SWFDEC_AS_NATIVE (1110, 1, swfdec_color_matrix_filter_get_matrix)
 SWFDEC_AS_NATIVE (1110, 2, swfdec_color_matrix_filter_set_matrix)
 SWFDEC_AS_NATIVE (1110, 0, swfdec_color_matrix_filter_contruct)
-SWFDEC_AS_NATIVE (1105, 101, swfdec_color_transform_get_alphaMultiplier)
-SWFDEC_AS_NATIVE (1105, 102, swfdec_color_transform_set_alphaMultiplier)
-SWFDEC_AS_NATIVE (1105, 103, swfdec_color_transform_get_redMultiplier)
-SWFDEC_AS_NATIVE (1105, 104, swfdec_color_transform_set_redMultiplier)
-SWFDEC_AS_NATIVE (1105, 105, swfdec_color_transform_get_greenMultiplier)
-SWFDEC_AS_NATIVE (1105, 106, swfdec_color_transform_set_greenMultiplier)
-SWFDEC_AS_NATIVE (1105, 107, swfdec_color_transform_get_blueMultiplier)
-SWFDEC_AS_NATIVE (1105, 108, swfdec_color_transform_set_blueMultiplier)
-SWFDEC_AS_NATIVE (1105, 109, swfdec_color_transform_get_alphaOffset)
-SWFDEC_AS_NATIVE (1105, 110, swfdec_color_transform_set_alphaOffset)
-SWFDEC_AS_NATIVE (1105, 111, swfdec_color_transform_get_redOffset)
-SWFDEC_AS_NATIVE (1105, 112, swfdec_color_transform_set_redOffset)
-SWFDEC_AS_NATIVE (1105, 113, swfdec_color_transform_get_greenOffset)
-SWFDEC_AS_NATIVE (1105, 114, swfdec_color_transform_set_greenOffset)
-SWFDEC_AS_NATIVE (1105, 115, swfdec_color_transform_get_blueOffset)
-SWFDEC_AS_NATIVE (1105, 116, swfdec_color_transform_set_blueOffset)
-SWFDEC_AS_NATIVE (1105, 117, swfdec_color_transform_get_rgb)
-SWFDEC_AS_NATIVE (1105, 118, swfdec_color_transform_set_rgb)
-SWFDEC_AS_NATIVE (1105, 1, swfdec_color_transform_concat)
-SWFDEC_AS_NATIVE (1105, 0, swfdec_color_transform_construct)
+SWFDEC_AS_NATIVE (1105, 101, swfdec_color_transform_as_get_alphaMultiplier)
+SWFDEC_AS_NATIVE (1105, 102, swfdec_color_transform_as_set_alphaMultiplier)
+SWFDEC_AS_NATIVE (1105, 103, swfdec_color_transform_as_get_redMultiplier)
+SWFDEC_AS_NATIVE (1105, 104, swfdec_color_transform_as_set_redMultiplier)
+SWFDEC_AS_NATIVE (1105, 105, swfdec_color_transform_as_get_greenMultiplier)
+SWFDEC_AS_NATIVE (1105, 106, swfdec_color_transform_as_set_greenMultiplier)
+SWFDEC_AS_NATIVE (1105, 107, swfdec_color_transform_as_get_blueMultiplier)
+SWFDEC_AS_NATIVE (1105, 108, swfdec_color_transform_as_set_blueMultiplier)
+SWFDEC_AS_NATIVE (1105, 109, swfdec_color_transform_as_get_alphaOffset)
+SWFDEC_AS_NATIVE (1105, 110, swfdec_color_transform_as_set_alphaOffset)
+SWFDEC_AS_NATIVE (1105, 111, swfdec_color_transform_as_get_redOffset)
+SWFDEC_AS_NATIVE (1105, 112, swfdec_color_transform_as_set_redOffset)
+SWFDEC_AS_NATIVE (1105, 113, swfdec_color_transform_as_get_greenOffset)
+SWFDEC_AS_NATIVE (1105, 114, swfdec_color_transform_as_set_greenOffset)
+SWFDEC_AS_NATIVE (1105, 115, swfdec_color_transform_as_get_blueOffset)
+SWFDEC_AS_NATIVE (1105, 116, swfdec_color_transform_as_set_blueOffset)
+SWFDEC_AS_NATIVE (1105, 117, swfdec_color_transform_as_get_rgb)
+SWFDEC_AS_NATIVE (1105, 118, swfdec_color_transform_as_set_rgb)
+SWFDEC_AS_NATIVE (1105, 1, swfdec_color_transform_as_concat)
 SWFDEC_AS_NATIVE (1109, 1, swfdec_convolution_filter_get_matrixX)
 SWFDEC_AS_NATIVE (1109, 2, swfdec_convolution_filter_set_matrixX)
 SWFDEC_AS_NATIVE (1109, 3, swfdec_convolution_filter_get_matrixY)
@@ -582,17 +583,16 @@ SWFDEC_AS_NATIVE (1067, 7, swfdec_text_snapshot_findText)
 SWFDEC_AS_NATIVE (1067, 8, swfdec_text_snapshot_setSelectColor)
 SWFDEC_AS_NATIVE (1067, 9, swfdec_text_snapshot_getTextRunInfo)
 SWFDEC_AS_NATIVE (1067, 0, swfdec_text_snapshot_construct)
-SWFDEC_AS_NATIVE (1106, 101, swfdec_transform_get_matrix)
-SWFDEC_AS_NATIVE (1106, 102, swfdec_transform_set_matrix)
-SWFDEC_AS_NATIVE (1106, 103, swfdec_transform_get_concatenatedMatrix)
-SWFDEC_AS_NATIVE (1106, 104, swfdec_transform_set_concatenatedMatrix)
-SWFDEC_AS_NATIVE (1106, 105, swfdec_transform_get_colorTransform)
-SWFDEC_AS_NATIVE (1106, 106, swfdec_transform_set_colorTransform)
-SWFDEC_AS_NATIVE (1106, 107, swfdec_transform_get_concatenatedColorTransform)
-SWFDEC_AS_NATIVE (1106, 108, swfdec_transform_set_concatenatedColorTransform)
-SWFDEC_AS_NATIVE (1106, 109, swfdec_transform_get_pixelBounds)
-SWFDEC_AS_NATIVE (1106, 110, swfdec_transform_set_pixelBounds)
-SWFDEC_AS_NATIVE (1106, 0, swfdec_transform_construct)
+SWFDEC_AS_NATIVE (1106, 101, swfdec_transform_as_get_matrix)
+SWFDEC_AS_NATIVE (1106, 102, swfdec_transform_as_set_matrix)
+SWFDEC_AS_NATIVE (1106, 103, swfdec_transform_as_get_concatenatedMatrix)
+SWFDEC_AS_NATIVE (1106, 104, swfdec_transform_as_set_concatenatedMatrix)
+SWFDEC_AS_NATIVE (1106, 105, swfdec_transform_as_get_colorTransform)
+SWFDEC_AS_NATIVE (1106, 106, swfdec_transform_as_set_colorTransform)
+SWFDEC_AS_NATIVE (1106, 107, swfdec_transform_as_get_concatenatedColorTransform)
+SWFDEC_AS_NATIVE (1106, 108, swfdec_transform_as_set_concatenatedColorTransform)
+SWFDEC_AS_NATIVE (1106, 109, swfdec_transform_as_get_pixelBounds)
+SWFDEC_AS_NATIVE (1106, 110, swfdec_transform_as_set_pixelBounds)
 SWFDEC_AS_NATIVE (667, 1, swfdec_video_attach_video)
 SWFDEC_AS_NATIVE (667, 2, swfdec_video_clear)
 SWFDEC_AS_NATIVE (253, 7, swfdec_xml_node_do_getNamespaceForPrefix)
@@ -621,11 +621,14 @@ SWFDEC_AS_CONSTRUCTOR (107, 2, swfdec_as_boolean_construct, swfdec_as_boolean_ge
 SWFDEC_AS_CONSTRUCTOR (103, 256, swfdec_as_date_construct, swfdec_as_date_get_type)
 SWFDEC_AS_CONSTRUCTOR (106, 2, swfdec_as_number_construct, swfdec_as_number_get_type)
 SWFDEC_AS_CONSTRUCTOR (251, 0, swfdec_as_string_construct, swfdec_as_string_get_type)
+SWFDEC_AS_CONSTRUCTOR (1100, 0, swfdec_bitmap_data_construct, swfdec_bitmap_data_get_type)
+SWFDEC_AS_CONSTRUCTOR (1105, 0, swfdec_color_transform_as_construct, swfdec_color_transform_as_get_type)
 SWFDEC_AS_CONSTRUCTOR (112, 0, swfdec_movie_clip_loader_construct, swfdec_movie_clip_loader_get_type)
 SWFDEC_AS_CONSTRUCTOR (2100, 200, swfdec_net_connection_construct, swfdec_net_connection_get_type)
 SWFDEC_AS_CONSTRUCTOR (500, 16, swfdec_sound_object_construct, swfdec_sound_object_get_type)
 SWFDEC_AS_CONSTRUCTOR (113, 0, swfdec_style_sheet_construct, swfdec_style_sheet_get_type)
 SWFDEC_AS_CONSTRUCTOR (110, 0, swfdec_text_format_construct, swfdec_text_format_get_type)
+SWFDEC_AS_CONSTRUCTOR (1106, 0, swfdec_transform_as_construct, swfdec_transform_as_get_type)
 SWFDEC_AS_CONSTRUCTOR (253, 0, swfdec_xml_node_construct, swfdec_xml_node_get_type)
 SWFDEC_AS_CONSTRUCTOR (253, 9, swfdec_xml_construct, swfdec_xml_get_type)
 SWFDEC_AS_NATIVE (1999, 0, swfdec_accessibility_isActive)
@@ -797,10 +800,9 @@ SWFDEC_AS_NATIVE (1100, 18, swfdec_bitmap_data_merge)
 SWFDEC_AS_NATIVE (1100, 19, swfdec_bitmap_data_noise)
 SWFDEC_AS_NATIVE (1100, 20, swfdec_bitmap_data_copyChannel)
 SWFDEC_AS_NATIVE (1100, 21, swfdec_bitmap_data_clone)
-SWFDEC_AS_NATIVE (1100, 22, swfdec_bitmap_data_dispose)
+SWFDEC_AS_NATIVE (1100, 22, swfdec_bitmap_data_do_dispose)
 SWFDEC_AS_NATIVE (1100, 23, swfdec_bitmap_data_generateFilterRect)
 SWFDEC_AS_NATIVE (1100, 24, swfdec_bitmap_data_compare)
-SWFDEC_AS_NATIVE (1100, 0, swfdec_bitmap_data_construct)
 SWFDEC_AS_NATIVE (1112, 1, swfdec_bitmap_filter_getPixel)
 SWFDEC_AS_NATIVE (1112, 0, swfdec_bitmap_filter_construct)
 SWFDEC_AS_NATIVE (1102, 1, swfdec_blur_filter_get_blurX)
@@ -835,26 +837,25 @@ SWFDEC_AS_NATIVE (700, 1, swfdec_movie_color_setTransform)
 SWFDEC_AS_NATIVE (1110, 1, swfdec_color_matrix_filter_get_matrix)
 SWFDEC_AS_NATIVE (1110, 2, swfdec_color_matrix_filter_set_matrix)
 SWFDEC_AS_NATIVE (1110, 0, swfdec_color_matrix_filter_contruct)
-SWFDEC_AS_NATIVE (1105, 101, swfdec_color_transform_get_alphaMultiplier)
-SWFDEC_AS_NATIVE (1105, 102, swfdec_color_transform_set_alphaMultiplier)
-SWFDEC_AS_NATIVE (1105, 103, swfdec_color_transform_get_redMultiplier)
-SWFDEC_AS_NATIVE (1105, 104, swfdec_color_transform_set_redMultiplier)
-SWFDEC_AS_NATIVE (1105, 105, swfdec_color_transform_get_greenMultiplier)
-SWFDEC_AS_NATIVE (1105, 106, swfdec_color_transform_set_greenMultiplier)
-SWFDEC_AS_NATIVE (1105, 107, swfdec_color_transform_get_blueMultiplier)
-SWFDEC_AS_NATIVE (1105, 108, swfdec_color_transform_set_blueMultiplier)
-SWFDEC_AS_NATIVE (1105, 109, swfdec_color_transform_get_alphaOffset)
-SWFDEC_AS_NATIVE (1105, 110, swfdec_color_transform_set_alphaOffset)
-SWFDEC_AS_NATIVE (1105, 111, swfdec_color_transform_get_redOffset)
-SWFDEC_AS_NATIVE (1105, 112, swfdec_color_transform_set_redOffset)
-SWFDEC_AS_NATIVE (1105, 113, swfdec_color_transform_get_greenOffset)
-SWFDEC_AS_NATIVE (1105, 114, swfdec_color_transform_set_greenOffset)
-SWFDEC_AS_NATIVE (1105, 115, swfdec_color_transform_get_blueOffset)
-SWFDEC_AS_NATIVE (1105, 116, swfdec_color_transform_set_blueOffset)
-SWFDEC_AS_NATIVE (1105, 117, swfdec_color_transform_get_rgb)
-SWFDEC_AS_NATIVE (1105, 118, swfdec_color_transform_set_rgb)
-SWFDEC_AS_NATIVE (1105, 1, swfdec_color_transform_concat)
-SWFDEC_AS_NATIVE (1105, 0, swfdec_color_transform_construct)
+SWFDEC_AS_NATIVE (1105, 101, swfdec_color_transform_as_get_alphaMultiplier)
+SWFDEC_AS_NATIVE (1105, 102, swfdec_color_transform_as_set_alphaMultiplier)
+SWFDEC_AS_NATIVE (1105, 103, swfdec_color_transform_as_get_redMultiplier)
+SWFDEC_AS_NATIVE (1105, 104, swfdec_color_transform_as_set_redMultiplier)
+SWFDEC_AS_NATIVE (1105, 105, swfdec_color_transform_as_get_greenMultiplier)
+SWFDEC_AS_NATIVE (1105, 106, swfdec_color_transform_as_set_greenMultiplier)
+SWFDEC_AS_NATIVE (1105, 107, swfdec_color_transform_as_get_blueMultiplier)
+SWFDEC_AS_NATIVE (1105, 108, swfdec_color_transform_as_set_blueMultiplier)
+SWFDEC_AS_NATIVE (1105, 109, swfdec_color_transform_as_get_alphaOffset)
+SWFDEC_AS_NATIVE (1105, 110, swfdec_color_transform_as_set_alphaOffset)
+SWFDEC_AS_NATIVE (1105, 111, swfdec_color_transform_as_get_redOffset)
+SWFDEC_AS_NATIVE (1105, 112, swfdec_color_transform_as_set_redOffset)
+SWFDEC_AS_NATIVE (1105, 113, swfdec_color_transform_as_get_greenOffset)
+SWFDEC_AS_NATIVE (1105, 114, swfdec_color_transform_as_set_greenOffset)
+SWFDEC_AS_NATIVE (1105, 115, swfdec_color_transform_as_get_blueOffset)
+SWFDEC_AS_NATIVE (1105, 116, swfdec_color_transform_as_set_blueOffset)
+SWFDEC_AS_NATIVE (1105, 117, swfdec_color_transform_as_get_rgb)
+SWFDEC_AS_NATIVE (1105, 118, swfdec_color_transform_as_set_rgb)
+SWFDEC_AS_NATIVE (1105, 1, swfdec_color_transform_as_concat)
 SWFDEC_AS_NATIVE (1109, 1, swfdec_convolution_filter_get_matrixX)
 SWFDEC_AS_NATIVE (1109, 2, swfdec_convolution_filter_set_matrixX)
 SWFDEC_AS_NATIVE (1109, 3, swfdec_convolution_filter_get_matrixY)
@@ -1196,17 +1197,16 @@ SWFDEC_AS_NATIVE (1067, 7, swfdec_text_snapshot_findText)
 SWFDEC_AS_NATIVE (1067, 8, swfdec_text_snapshot_setSelectColor)
 SWFDEC_AS_NATIVE (1067, 9, swfdec_text_snapshot_getTextRunInfo)
 SWFDEC_AS_NATIVE (1067, 0, swfdec_text_snapshot_construct)
-SWFDEC_AS_NATIVE (1106, 101, swfdec_transform_get_matrix)
-SWFDEC_AS_NATIVE (1106, 102, swfdec_transform_set_matrix)
-SWFDEC_AS_NATIVE (1106, 103, swfdec_transform_get_concatenatedMatrix)
-SWFDEC_AS_NATIVE (1106, 104, swfdec_transform_set_concatenatedMatrix)
-SWFDEC_AS_NATIVE (1106, 105, swfdec_transform_get_colorTransform)
-SWFDEC_AS_NATIVE (1106, 106, swfdec_transform_set_colorTransform)
-SWFDEC_AS_NATIVE (1106, 107, swfdec_transform_get_concatenatedColorTransform)
-SWFDEC_AS_NATIVE (1106, 108, swfdec_transform_set_concatenatedColorTransform)
-SWFDEC_AS_NATIVE (1106, 109, swfdec_transform_get_pixelBounds)
-SWFDEC_AS_NATIVE (1106, 110, swfdec_transform_set_pixelBounds)
-SWFDEC_AS_NATIVE (1106, 0, swfdec_transform_construct)
+SWFDEC_AS_NATIVE (1106, 101, swfdec_transform_as_get_matrix)
+SWFDEC_AS_NATIVE (1106, 102, swfdec_transform_as_set_matrix)
+SWFDEC_AS_NATIVE (1106, 103, swfdec_transform_as_get_concatenatedMatrix)
+SWFDEC_AS_NATIVE (1106, 104, swfdec_transform_as_set_concatenatedMatrix)
+SWFDEC_AS_NATIVE (1106, 105, swfdec_transform_as_get_colorTransform)
+SWFDEC_AS_NATIVE (1106, 106, swfdec_transform_as_set_colorTransform)
+SWFDEC_AS_NATIVE (1106, 107, swfdec_transform_as_get_concatenatedColorTransform)
+SWFDEC_AS_NATIVE (1106, 108, swfdec_transform_as_set_concatenatedColorTransform)
+SWFDEC_AS_NATIVE (1106, 109, swfdec_transform_as_get_pixelBounds)
+SWFDEC_AS_NATIVE (1106, 110, swfdec_transform_as_set_pixelBounds)
 SWFDEC_AS_NATIVE (667, 1, swfdec_video_attach_video)
 SWFDEC_AS_NATIVE (667, 2, swfdec_video_clear)
 SWFDEC_AS_NATIVE (253, 7, swfdec_xml_node_do_getNamespaceForPrefix)
